pub enum BackgroundClip {
BorderBox,
PaddingBox,
ContentBox,
Border,
Text,
}Expand description
A value for the background-clip property.
Variants
BorderBox
The background is clipped to the border box.
PaddingBox
The background is clipped to the padding box.
ContentBox
The background is clipped to the content box.
Border
The background is clipped to the area painted by the border.
Text
The background is clipped to the text content of the element.
Implementations