Struct lightningcss::rules::CssRuleList
source · pub struct CssRuleList<'i, R = DefaultAtRule>(pub Vec<CssRule<'i, R>>);Expand description
A list of CSS rules.
Tuple Fields
0: Vec<CssRule<'i, R>>Implementations
sourceimpl<'i> CssRuleList<'i, DefaultAtRule>
impl<'i> CssRuleList<'i, DefaultAtRule>
sourcepub fn parse<'t>(
input: &mut Parser<'i, 't>,
options: &ParserOptions<'_, 'i>
) -> Result<Self, ParseError<'i, ParserError<'i>>>
pub fn parse<'t>( input: &mut Parser<'i, 't>, options: &ParserOptions<'_, 'i> ) -> Result<Self, ParseError<'i, ParserError<'i>>>
Parse a rule list.
sourcepub fn parse_style_block<'t>(
input: &mut Parser<'i, 't>,
options: &ParserOptions<'_, 'i>,
is_nested: bool
) -> Result<Self, ParseError<'i, ParserError<'i>>>
pub fn parse_style_block<'t>( input: &mut Parser<'i, 't>, options: &ParserOptions<'_, 'i>, is_nested: bool ) -> Result<Self, ParseError<'i, ParserError<'i>>>
Parse a style block, with both declarations and rules. Resulting declarations are returned in a nested style rule.
sourceimpl<'i, T> CssRuleList<'i, T>
impl<'i, T> CssRuleList<'i, T>
sourcepub fn parse_with<'t, P: AtRuleParser<'i, AtRule = T>>(
input: &mut Parser<'i, 't>,
options: &ParserOptions<'_, 'i>,
at_rule_parser: &mut P
) -> Result<Self, ParseError<'i, ParserError<'i>>>
pub fn parse_with<'t, P: AtRuleParser<'i, AtRule = T>>( input: &mut Parser<'i, 't>, options: &ParserOptions<'_, 'i>, at_rule_parser: &mut P ) -> Result<Self, ParseError<'i, ParserError<'i>>>
Parse a rule list with a custom at rule parser.
sourcepub fn parse_style_block_with<'t, P: AtRuleParser<'i, AtRule = T>>(
input: &mut Parser<'i, 't>,
options: &ParserOptions<'_, 'i>,
at_rule_parser: &mut P,
is_nested: bool
) -> Result<Self, ParseError<'i, ParserError<'i>>>
pub fn parse_style_block_with<'t, P: AtRuleParser<'i, AtRule = T>>( input: &mut Parser<'i, 't>, options: &ParserOptions<'_, 'i>, at_rule_parser: &mut P, is_nested: bool ) -> Result<Self, ParseError<'i, ParserError<'i>>>
Parse a style block, with both declarations and rules. Resulting declarations are returned in a nested style rule.