Module color

CSS color values.

Structs

A98
A color in the a98-rgb color space.
ChannelType
A channel type for a color space.
ColorFallbackKind
A color type that is used as a fallback when compiling colors for older browsers.
HSL
A color in the hsl color space.
HWB
A color in the hwb color space.
LAB
A color in the CIE Lab color space.
LCH
A color in the CIE LCH color space.
OKLAB
A color in the OKLab color space.
OKLCH
A color in the OKLCH color space.
P3
A color in the display-p3 color space.
ProPhoto
A color in the prophoto-rgb color space.
RGBA
A color with red, green, blue, and alpha components, in a byte each.
Rec2020
A color in the rec2020 color space.
SRGB
A color in the sRGB color space.
SRGBLinear
A color in the sRGB-linear color space.
XYZd50
A color in the xyz-d50 color space.
XYZd65
A color in the xyz-d65 color space.

Enums

CssColor
A CSS <color> value.
FloatColor
A floating point representation of color types that are usually stored as RGBA. These are used when there are any none components, which are represented as NaN.
HueInterpolationMethod
A hue interpolation method used in interpolation functions such as color-mix().
LABColor
A color in a LAB color space, including the lab(), lch(), oklab(), and oklch() functions.
PredefinedColor
A color in a predefined color space, e.g. display-p3.
SystemColor
A CSS system color keyword.

Traits

ColorGamut
A trait that colors implement to support gamut mapping.
ColorSpace
A trait for color spaces.
Interpolate
A trait that colors implement to support interpolation.