pub enum CssColor {
    CurrentColor,
    RGBA(RGBA),
    LAB(Box<LABColor>),
    Predefined(Box<PredefinedColor>),
    Float(Box<FloatColor>),
}
A CSS <color> value.

CSS supports many different color spaces to represent colors. The most common values are stored as RGBA using a single byte per component. Less common values are stored using a Box to reduce the amount of memory used per color.

Each color space is represented as a struct that implements the From and Into traits for all other color spaces, so it is possible to convert between color spaces easily. In addition, colors support interpolation as in the color-mix() function.

Variants



CurrentColor

The currentColor keyword.



RGBA(RGBA)

An value in the RGB color space, including values parsed as hex colors, or the rgb(), hsl(), and hwb() functions.



LAB(Box<LABColor>)

A value in a LAB color space, including the lab(), lch(), oklab(), and oklch() functions.



Predefined(Box<PredefinedColor>)

A value in a predefined color space, e.g. display-p3.



Float(Box<FloatColor>)

A floating point representation of an RGB, HSL, or HWB color when it contains none components.

Implementations

source

impl CssColor

source

pub fn current_color() -> CssColor

Returns the currentColor keyword.

source

pub fn transparent() -> CssColor

Returns the transparent keyword.

source

pub fn to_rgb(&self) -> Result<CssColor, ()>

Converts the color to RGBA.

source

pub fn to_lab(&self) -> Result<CssColor, ()>

Converts the color to the LAB color space.

source

pub fn to_p3(&self) -> Result<CssColor, ()>

Converts the color to the P3 color space.

source

pub fn get_necessary_fallbacks(&self, targets: Targets) -> ColorFallbackKind

Returns the color fallback types needed for the given browser targets.

source

pub fn get_fallback(&self, kind: ColorFallbackKind) -> CssColor

Returns a fallback color for the given fallback type.

source

impl CssColor

source

pub fn interpolate<'a, T>( &'a self, p1: f32, other: &'a CssColor, p2: f32, method: HueInterpolationMethod ) -> Result<CssColor, ()>where T: 'static + TryFrom<&'a CssColor> + Interpolate + Into<CssColor> + Into<OKLCH> + ColorGamut + Into<OKLAB> + From<OKLCH> + Copy,

Mixes this color with another color, including the specified amount of each. Implemented according to the color-mix() function.