CSS color values.
Structs
- A98
- A color in the
a98-rgbcolor space. - Channel
Type - A channel type for a color space.
- Color
Fallback Kind - A color type that is used as a fallback when compiling colors for older browsers.
- HSL
- A color in the
hslcolor space. - HWB
- A color in the
hwbcolor space. - LAB
- A color in the CIE Lab color space.
- LCH
- A color in the CIE LCH color space.
- OKLAB
- A color in the OKLab color space.
- OKLCH
- A color in the OKLCH color space.
- P3
- A color in the
display-p3color space. - ProPhoto
- A color in the
prophoto-rgbcolor space. - RGBA
- A color with red, green, blue, and alpha components, in a byte each.
- Rec2020
- A color in the
rec2020color space. - SRGB
- A color in the
sRGBcolor space. - SRGB
Linear - A color in the
sRGB-linearcolor space. - XYZd50
- A color in the
xyz-d50color space. - XYZd65
- A color in the
xyz-d65color space.
Enums
- CssColor
- A CSS
<color>value. - Float
Color - A floating point representation of color types that
are usually stored as RGBA. These are used when there
are any
nonecomponents, which are represented as NaN. - HueInterpolation
Method - A hue interpolation method
used in interpolation functions such as
color-mix(). - LABColor
- A color in a LAB color space, including the
lab(),lch(),oklab(), andoklch()functions. - Predefined
Color - A color in a predefined color space, e.g.
display-p3. - System
Color - A CSS system color keyword.
Traits
- Color
Gamut - A trait that colors implement to support gamut mapping.
- Color
Space - A trait for color spaces.
- Interpolate
- A trait that colors implement to support interpolation.